import React, { useRef } from 'react'
import { Button, Card, Form, Input, Select, Row, Col } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormRadio,
} from '@ant-design/pro-components'
import useBool from '@/utils/hooks/useBool'
import { useSearchParams, useNavigate } from 'react-router-dom'
import Page from '@/components/Page'
import { formItemLayout, tailFormItemLayout } from '@/utils/form'
import { postTaCustom, putTaCustom, getTaCustomId } from '@/services/taCustom'
const { Option } = Select

export default (props) => {
  const formRef = useRef()
  const [submiting, startSubmit, cancelSubmit] = useBool()

  const [searchParams] = useSearchParams()
  const navigate = useNavigate()

  const id = searchParams.get('id')

  React.useEffect(() => {
    if (id) {
      getTaCustomId(id).then((res) => {
        formRef.current?.setFieldsValue(res)
      })
    }
  })

  const onFinish = (values) => {
    startSubmit()
    if (id) {
      //修改
      const customId = id
      putTaCustom(id, { customId, ...values })
        .then((res) => {
          cancelSubmit()
          navigate(-1)
        })
        .catch(() => {
          cancelSubmit()
        })
    } else {
      //新增
      postTaCustom(values)
        .then((res) => {
          cancelSubmit()
          navigate(-1)
        })
        .catch(() => {
          cancelSubmit()
        })
    }
  }

  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          {...formItemLayout}
          submitter={{
            render: (_, doms) => [
              <Row>
                <Col offset={6}>
                  <Button type="primary" htmlType="submit">
                    提交
                  </Button>
                </Col>
                <Col offset={1}>
                  <Button onClick={() => navigate(-1)}>返回</Button>
                </Col>
              </Row>,
            ],
          }}
        >
          <ProFormText name="customName" label="客户名" />
          <ProFormText name="dutyParagraph" label="客户税号" />
          <ProFormText name="openingBank" label="开户行" />
          <ProFormText name="account" label="客户账号" />
          <ProFormText name="contactsName" label="联系人姓名" />
          <ProFormText name="contactsTitle" label="联系人头衔" />
          <ProFormText name="contactsPhone" label="联系人手机" />
          <ProFormText name="contactsEmail" label="联系人邮箱" />
          <ProFormRadio.Group
            name="isOrg"
            label="是否企业"
            options={[
              { label: '否', value: 0 },
              { label: '是', value: 1 },
            ]}
          />
        </ProForm>
      </Card>
    </Page>
  )
}
