import React from "react";
import { Button, Form, Input, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { postDept, putDeptId } from "@/services/sysDept";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";

export default (props) => {
  const { dept, list, parentId, onChange } = props;

  const [submiting, startSubmit, cancelSubmit] = useBool();
  const [form] = Form.useForm();
  const onFinish = (values) => {
    startSubmit();
    if (dept?.deptId) {
      // 修改
      putDeptId(dept.deptId, values)
        .then((res) => {
          cancelSubmit();
          onChange(res);
        })
        .catch(() => {
          cancelSubmit();
        });
    } else {
      // 新增
      postDept(values)
        .then((res) => {
          cancelSubmit();
          onChange(res);
        })
        .catch(() => {
          cancelSubmit();
        });
    }
  };

  React.useEffect(() => {
    form.resetFields();
    if (dept) {
      form.setFieldsValue(dept);
    } else {
      form.setFieldValue("parentId", parentId);
    }

  }, [dept, parentId]);

  return (
    <Form
      form={form}
      {...formItemLayout}
      style={{ maxWidth: "800px" }}
      onFinish={onFinish}
    >
      <Form.Item
        name="deptName"
        label="部门名称"
        rules={[{ required: true, message: "请填写部门名称" }]}
      >
        <Input />
      </Form.Item>
      <Form.Item
        name="tenantName"
        label="租户名称"
        rules={[{ required: true, message: "请填写租户名称" }]}
      >
        <Input />
      </Form.Item>
      <Form.Item name="parentId" label="上级单位">
        <Select disabled={true}>
          {(list || []).map((x) => (
            <Select.Option key={x.deptId}>{x.deptName}</Select.Option>
          ))}
        </Select>
      </Form.Item>
      <Form.Item
        name="sortNo"
        label="排序"
        rules={[{ required: true, message: "请填写排序" }]}
      >
        <Input />
      </Form.Item>

      {/* <Form.Item
        name="status"
        label="状态"
        initialValue={1}
        rules={[{ required: true, message: "请填写状态" }]}
      >
        <Select style={{ width: "100%" }} placeholder="请选择状态">
          <Select.Option value={0}>禁用</Select.Option>
          <Select.Option value={1}>启用</Select.Option>
        </Select>
      </Form.Item> */}
      <Form.Item {...tailFormItemLayout}>
        <Button loading={submiting} type="primary" htmlType="submit">
          保存
        </Button>
      </Form.Item>
    </Form>
  );
};
