import React from "react";
import { Modal } from "antd";
import PureList from "@/components/Page/PureList";
import AuthSwitch from "@/components/Auth/AuthSwitch";
import Form from "./Form";
import { getDept, deleteDeptId } from "@/services/sysDept";

export default (props) => {
  const { parentId = -1, allData, onFinish } = props;

  const [current, setCurrernt] = React.useState();
  const [open, setOpen] = React.useState(false);
  const params = React.useMemo(() => ({ parentId }), [parentId]);
  const listRef = React.useRef();

  const columns = [
    {
      title: "部门名称",
      dataIndex: "deptName",
    },
    {
      title: "租户名称",
      dataIndex: "tenantName",
      search: false,
    },
    {
      title: "排序",
      dataIndex: "sortNo",
      search: false,
    },
    // {
    //   title: "状态",
    //   dataIndex: "status",
    //   search: false,
    //   render: (_, row) => (
    //     <AuthSwitch
    //       checkedChildren="启用"
    //       unCheckedChildren="禁用"
    //       checked={row.status == 1}
    //       fallback={row.status == 1 ? '启用' : '禁用'}
    //       onChange={(checked) => onStatusChange(row, checked)}
    //     />
    //   )
    // },
  ];

  const onStatusChange = () => {};

  const onAdd = () => {
    setCurrernt({ parentId });
    setOpen(true);
  };

  const onEdit = (row) => {
    setCurrernt(row);
    setOpen(true);
  };

  const onDelete = (row) => {
    deleteDeptId(row?.deptId)
      .then(() => {
        listRef.current.reload();
      })
      .catch((err) => {});
  };

  const handleFinish = () => {
    setOpen(false);
    listRef.current.reload();
    onFinish();
  };

  return (
    <>
      <PureList
        rowKey="deptId"
        ref={listRef}
        columns={columns}
        request={getDept}
        params={params}
        onAdd={onAdd}
        onEdit={onEdit}
        onDelete={onDelete}
      />
      <Modal
        title="部门维护"
        open={open}
        footer={null}
        maskClosable={false}
        onCancel={() => setOpen(false)}
      >
        <Form
          dept={current}
          parentId={parentId}
          list={allData}
          onChange={handleFinish}
        />
      </Modal>
    </>
  );
};
